pub struct Cursor<'a> { /* private fields */ }Expand description
Peekable iterator over a char sequence.
Next characters can be peeked via first method,
and position can be shifted forward via bump method.
Implementations
Sourceimpl<'a> Cursor<'a>
impl<'a> Cursor<'a>
Sourcepub fn with_position(self) -> CursorWithPosition<'a> ⓘ
pub fn with_position(self) -> CursorWithPosition<'a> ⓘ
Creates a new iterator that also returns the position of each token in the input string.
Note that the position currently always starts at 0 when this method is called, so if called after tokens are parsed the position will be relative to when this method is called, not the beginning of the string.