pub struct Lexer<'sess, 'src> { /* private fields */ }Expand description
Solidity and Yul lexer.
Converts a Cursor’s output from simple RawTokenKinds into rich TokenKinds, by
converting strings into interned symbols, and running additional validation.
Implementations
Sourceimpl<'sess, 'src> Lexer<'sess, 'src>
impl<'sess, 'src> Lexer<'sess, 'src>
Sourcepub fn new(sess: &'sess Session, src: &'src str) -> Self
pub fn new(sess: &'sess Session, src: &'src str) -> Self
Creates a new Lexer for the given source string.
Sourcepub fn from_source_file(sess: &'sess Session, file: &'src SourceFile) -> Self
pub fn from_source_file(sess: &'sess Session, file: &'src SourceFile) -> Self
Creates a new Lexer for the given source file.
Note that the source file must be added to the source map before calling this function.
Sourcepub fn with_start_pos(
sess: &'sess Session,
src: &'src str,
start_pos: BytePos,
) -> Self
pub fn with_start_pos( sess: &'sess Session, src: &'src str, start_pos: BytePos, ) -> Self
Creates a new Lexer for the given source string and starting position.
Sourcepub fn into_tokens(self) -> Vec<Token>
pub fn into_tokens(self) -> Vec<Token>
Consumes the lexer and collects the remaining tokens into a vector.
Note that this skips comments, as required by the parser.
Prefer using this method instead of manually collecting tokens using Iterator.