Module natspec
solar_
parse
0.2.0
Module natspec
Module Items
Functions
In crate solar_
parse
solar_parse
Module
natspec
Functions

first_
word
Returns the first non-blank word and the position of the first following non-blank char.
split_
once_
ws
Splits a string slice at the first whitespace character.