split_once_ws

Function split_once_ws 

pub fn split_once_ws(content: &str, start: usize, end: usize) -> (&str, usize)
Splits a string slice at the first whitespace character.

Returns the content up to the whitespace and the position of the first following non-blank char.